@@ -69,7 +69,7 @@ class CGFeedMaker extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.0.15';
+    return '1.0.16';
   }
 
 
@@ -78,7 +78,7 @@ class CGFeedMaker extends CGExtensions
    ---------------------------------------------------------*/
   function GetHelp()
   {
-    return $this->Lang('help');
+    return @file_get_contents(dirname(__FILE__).'/help.inc');
   }
 
 
@@ -153,12 +153,23 @@ class CGFeedMaker extends CGExtensions
   }
 
 
+  /*---------------------------------------------------------
+   LazyLoadAdmin()
+   
+   For version 1.10+
+   ---------------------------------------------------------*/
+  function LazyLoadAdmin()
+  {
+    return $this->CheckPermission('Manage RSS Feeds');
+  }
+
+
   /*---------------------------------------------------------
    GetDependencies()
    ---------------------------------------------------------*/
   function GetDependencies()
   {
-    return array('CGExtensions'=>'1.20');
+    return array('CGExtensions'=>'1.28');
   }
 
 
